unit Calculator_Main;

{$MODE Delphi}

//---------------------------------------------------------------------------
//   Calculator version 1.5
//   Copyright (C) 2000-2001 FUJIMAKI Haruyuki
//   TQG00473@nifty.com
//   fujimaki@sakura.cc.tsukuba.ac.jp
//---------------------------------------------------------------------------

interface

uses
  SysUtils, Classes, Controls, Graphics,Forms, LResources, Buttons,
  StdCtrls, ExtCtrls, Dialogs, Clipbrd, unix, MathsParser;

type

  { TMain }

  TMain = class(TForm)
    ComboBox1: TComboBox;
    BitBtn1: TBitBtn;
    BitBtn2: TBitBtn;
    BitBtn4: TBitBtn;
    BitBtn3: TBitBtn;
    Edit1: TEdit;
    EditA: TEdit;
    EditB: TEdit;
    EditC: TEdit;
    EditD: TEdit;
    EditE: TEdit;
    Label1: TLabel;
    Label2: TLabel;
    Label3: TLabel;
    Label4: TLabel;
    Label5: TLabel;
    Label6: TLabel;
    Panel1: TPanel;
    Panel2: TPanel;
    Panel3: TPanel;
    Panel4: TPanel;
    Panel5: TPanel;
    MathsParser1: TMathsParser;
    SpeedButton2: TSpeedButton;
    procedure BitBtn1Click(Sender: TObject);
    procedure BitBtn2Click(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure FormCreate(Sender: TObject);
    procedure BitBtn4Click(Sender: TObject);
    procedure BitBtn3Click(Sender: TObject);
    procedure FormKeyDown(Sender: TObject; var Key: Word;
      Shift: TShiftState);
    procedure ComboBox1Change(Sender: TObject);
    procedure ComboBox1KeyUp(Sender: TObject; var Key: Word;
      Shift: TShiftState);
    procedure FormShow(Sender: TObject);
  private

  public

  end;

var
  Main: TMain;
  Modified : Boolean;
  StockBitMap: TBitmap;

implementation


procedure TMain.FormCreate(Sender: TObject);
begin
  StockBitMap := TBitmap.Create;
  if FileExists(ExtractFilePath(Application.Exename) +  'Expressions.txt') then
    ComboBox1.Items.LoadFromFile(ExtractFilePath(Application.Exename) +  'Expressions.txt');
  Modified := False;
end;

procedure TMain.BitBtn1Click(Sender: TObject);
var
  eq: String;
begin
  eq := Copy(ComboBox1.Text, Pos(':', ComboBox1.Text) + 1, 1000);
  with MathsParser1 do
  begin
    Expression := eq;
    V1 := StrToFloat(EditA.Text);
    V2 := StrToFloat(EditB.Text);
    V3 := StrToFloat(EditC.Text);
    V4 := StrToFloat(EditD.Text);
    V5 := StrToFloat(EditE.Text);
    Edit1.Text := FloatToStr(Value)
  end;
  BitBtn4.SetFocus;
  Application.ProcessMessages;
  ComboBox1.SetFocus;
end;

procedure TMain.BitBtn2Click(Sender: TObject);
begin
{$ifdef Linux}
  shell('firefox ' + ExtractFilePath(Application.ExeName) + 'Help.htm');
{$else}
  ShellExecute(Handle, 'open', PChar(ExtractFileDir(Application.ExeName) + '\Help.htm'), nil, PChar(ExtractFileDrive(Application.ExeName)), SW_SHOW);
{$endif}
end;

procedure TMain.FormClose(Sender: TObject; var Action: TCloseAction);
begin
  ComboBox1.Items.SaveToFile(ExtractFilePath(Application.Exename) + 'Expressions.txt');
  StockBitMap.Free;
end;

procedure TMain.BitBtn4Click(Sender: TObject);
begin
  Clipboard.AsText := Edit1.Text;
end;

procedure TMain.BitBtn3Click(Sender: TObject);
var i : ShortInt;
begin
  if BitBtn3.Caption = '&Register' then
  begin
    if MessageDlg('Are you sure you want to register this expression?', mtConfirmation, [mbYes, mbNo], 0) = mrYes then
      with ComboBox1 do
      begin
        Items.Add(Items.Strings[Items.Count-1]);
        for i := Items.Count - 1 downto 1 do
          Items.Strings[i] := Items.Strings[i-1];
        Items.Strings[0] := Text
      end;
  end
  else
  begin
    if MessageDlg('Are you sure you want to delete this expression from the list?', mtConfirmation, [mbYes, mbNo], 0) = mrYes then
      with ComboBox1 do
        Items.Delete(ItemIndex);
  end;
end;

procedure TMain.FormKeyDown(Sender: TObject; var Key: Word;
  Shift: TShiftState);
begin
{$ifdef Linux}
  if Key = 4000 then
{$else}
  if Key = VK_F1 then
    BitBtn2Click(Sender)
{$endif}
end;

procedure TMain.ComboBox1Change(Sender: TObject);
var i: Word;
begin
  if ComboBox1.ItemIndex > 0 then
  begin
    if ComboBox1.Text = ComboBox1.Items.Strings[ComboBox1.ItemIndex] then
    begin
      BitBtn3.Caption := '&Delete';
      StockBitMap.Assign(BitBtn3.Glyph);
      BitBtn3.Glyph := SpeedButton2.Glyph;
    end
    else
    begin
      BitBtn3.Caption := '&Register';
      BitBtn3.Glyph := StockBitMap;
    end;
    if ComboBox1.Items[ComboBox1.ItemIndex] = ComboBox1.Text then
    begin
      MathsParser1.V1Name := 'a';
      MathsParser1.V2Name := 'b';
      MathsParser1.V3Name := 'c';
      MathsParser1.V4Name := 'd';
      MathsParser1.V5Name := 'e';
    end;
    i := 1;
    ComboBox1KeyUp(Sender, i, []);
  end;
end;

procedure TMain.ComboBox1KeyUp(Sender: TObject; var Key: Word;
  Shift: TShiftState);
var
  S: String;
begin
  {$ifdef Linux}
    if Key = 4100 then
      BitBtn1Click(Sender);
  {$else}
    BitBtn1.Default := True;
  {$endif}
  S := Copy(ComboBox1.Text, Pos(':', ComboBox1.Text) + 1, 1000);
  MathsParser1.DetectVariables(S);
  Panel1.Caption := MathsParser1.V1Name;
  Panel2.Caption := MathsParser1.V2Name;
  Panel3.Caption := MathsParser1.V3Name;
  Panel4.Caption := MathsParser1.V4Name;
  Panel5.Caption := MathsParser1.V5Name;
end;

procedure TMain.FormShow(Sender: TObject);
begin
  ComboBox1.SetFocus;
end;

initialization
  {$i Calculator_Main.lrs}

end.
